"""
The :mod:`numpy <scisalt.numpy>` module contains a few convenience functions mostly designed to make evaluating functions easier for plotting.
"""
__all__ = ['frexp10', 'linspaceborders', 'linspacestep']
from .frexp10 import *
from .linspaceborders import *
from .linspacestep import *
